KlineState class

Inheritance
Mixed-in types

Constructors

KlineState()

Properties

autoSize bool
getter/setter pair
bgLineRepaintFlag int
getter/setter pair
candleRepaintFlag int
getter/setter pair
chartData ChartData
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
crossRepaintFlag int
getter/setter pair
crossTipPro Map
getter/setter pair
cTipPro Map
getter/setter pair
currentPosition Offset
getter/setter pair
currentStyle Map
getter/setter pair
cursorType String
getter/setter pair
depth DepthPathCalculation
getter/setter pair
depthRepaintFlag int
getter/setter pair
downPointID int
getter/setter pair
draw DrawCalculation
getter/setter pair
drawPath Map
getter/setter pair
drawToolPro Map
getter/setter pair
fpsController Timer
getter/setter pair
futureLoadK bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hlocPro Map
getter/setter pair
indicator Indicatorcalculation
getter/setter pair
isDownSelOther bool
getter/setter pair
isInWeb bool
getter/setter pair
isMayPreLoad bool
getter/setter pair
isNoData bool
getter/setter pair
isPopZbSet bool
getter/setter pair
isPortrait bool
getter/setter pair
isShowDrawTool bool
getter/setter pair
klineBox Map<String, double>
getter/setter pair
kMouseIsIn bool
getter/setter pair
magnifier Map
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
mouseScrollScale double
getter/setter pair
mouseScrollTimer Timer?
getter/setter pair
movePosition Offset
getter/setter pair
moveStatus TapMoveStatus
getter/setter pair
mType int
getter/setter pair
p KlinePathcalCulation
getter/setter pair
prekSx num
getter/setter pair
preLastKH num
getter/setter pair
preLastKL num
getter/setter pair
preLoadK bool
getter/setter pair
preTime String
getter/setter pair
priceRepaintFlag int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleInitIndex int
getter/setter pair
scaleInitKw double
getter/setter pair
setCodeEnd bool
getter/setter pair
setZbData Map?
getter/setter pair
tapPosition Offset
getter/setter pair
tapStatus TapStatus
getter/setter pair
testNum int
getter/setter pair
theme Themes
getter/setter pair
twoFingerMoveTimer Timer?
getter/setter pair
twoFingerPointX double
getter/setter pair
twoFingerPointY double
getter/setter pair
widget FlutterKlineChart
The current configuration.
no setterinherited
zbSetPro Map
getter/setter pair
zoomStatus ZoomStatus
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
callCancle(dynamic value) → dynamic
callCancleAdd(dynamic value) → dynamic
callCancleUpdate(dynamic value) → dynamic
callDepth(dynamic value) → dynamic
callPath() → dynamic
callSize(dynamic context) → void
cancelTimer() → void
candleChart() Widget
createTicker(TickerCallback onTick) Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
depthChart() Widget
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant FlutterKlineChart oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
downIsMove() bool
hideCrossLine() → dynamic
initState() → void
Called when this object is inserted into the tree.
override
k() Widget
keepStopDraw() → dynamic
longPress(dynamic event) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(dynamic value) → dynamic
onPointerSignal(dynamic event) → dynamic
onScaleEnd(ScaleEndDetails details) → dynamic
onScaleStart(ScaleStartDetails details) → dynamic
onScaleUpdate(ScaleUpdateDetails details) → dynamic
onTapDown(dynamic event) → dynamic
onTapMove(dynamic event) → dynamic
onTapUp(dynamic event) → dynamic
onWebEnter(dynamic event) → dynamic
onWebExit(dynamic event) → dynamic
onWebHover(dynamic event) → dynamic
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resumePress() → dynamic
set(dynamic value) → dynamic
setMkDataToLast() → dynamic
setSize() → dynamic
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
sizeControl() → dynamic
stopDraw() → dynamic
stopMouseScrollScale() → dynamic
stopTwoFingerMove() → dynamic
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateInitKlineIndex(dynamic kl) → dynamic
updateState(Timer time) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited