HLOCInfo class

Inheritance

Constructors

HLOCInfo({Key? key, required FlutterKlineChart widget, required KlinePathcalCulation p, required Map style, required bool isWeb, required Map hlocPro})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hlocPro Map
final
isWeb bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
p KlinePathcalCulation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Map
final
widget FlutterKlineChart
final

Methods

appContainer() Widget
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getTxtWidth(dynamic text, dynamic txtStyle) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
webContainer() Widget

Operators

operator ==(Object other) bool
The equality operator.
inherited