Themes class

Constructors

Themes()

Properties

dark Map
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initTheme Map
getter/setter pair
isWeb bool
getter/setter pair
light Map
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTheme(dynamic value) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColorRule(dynamic colorRule) → dynamic
设置颜色规则 redUp红涨绿跌 greenUp绿涨红跌
setDirectionRule(dynamic textDirection) → dynamic
设置文字排版 ltr 从左到右 tlr 从右到左
setHlocFontStyle(dynamic style) → dynamic
setIsWeb(dynamic value) → dynamic
setThemeStyle(Map darkTheme, Map lightTheme, dynamic colorRule, dynamic textDirection) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited