DepthPathCalculation class
Constructors
- DepthPathCalculation(KlineState klineState, Map style, ChartData chartData)
Properties
- chartData ↔ ChartData
-
getter/setter pair
- depthRepaintFlag ↔ int
-
getter/setter pair
- drawPath ↔ Map
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- klineState ↔ KlineState
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sscale ↔ double
-
getter/setter pair
- style ↔ Map
-
getter/setter pair
- sxh ↔ double
-
getter/setter pair
- sxts ↔ Map
-
getter/setter pair
- symax ↔ double
-
getter/setter pair
- symaxStr ↔ String
-
getter/setter pair
- symin ↔ double
-
getter/setter pair
- syminStr ↔ String
-
getter/setter pair
- syts ↔ Map
-
getter/setter pair
- syw ↔ double
-
getter/setter pair
Methods
-
callMM(
) → dynamic -
callPath(
dynamic x, dynamic y, dynamic w, dynamic h) → dynamic -
depthLine(
dynamic x, dynamic y, dynamic w, dynamic h) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setStyle(
dynamic style) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited