TakeType enum
Values
- themeType → const TakeType
- colorRule → const TakeType
- language → const TakeType
- timeZone → const TakeType
- mainIndicator → const TakeType
- attachedIndicator → const TakeType
- attachedIndicatorHeight → const TakeType
- indicatorParams → const TakeType
- codeInterval → const TakeType
- firstKlineData → const TakeType
- moreKlineData → const TakeType
- newKline → const TakeType
- orderBookData → const TakeType
- chartType → const TakeType
- tradeMarksData → const TakeType
- kolMarksData → const TakeType
- marksData → const TakeType
- orderTradeData → const TakeType
- postionTradeData → const TakeType
- goToTime → const TakeType
- drawLine → const TakeType
- clickTradeData → const TakeType
- dragTradeData → const TakeType
- clickTradeMarks → const TakeType
- clickKolMarks → const TakeType
- clickMark → const TakeType
- clickAddTrade → const TakeType
- clickZbSet → const TakeType
- popZbSet → const TakeType
- setOrientation → const TakeType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited